@@ -20,7 +20,6 @@
 #ifndef __CTK_POWERMIZER_H__
 #define __CTK_POWERMIZER_H__
 
-#include "NvCtrlAttributes.h"
 #include "ctkconfig.h"
 #include "ctkevent.h"
 
@@ -50,7 +49,7 @@ struct _CtkPowermizer
 {
     GtkVBox parent;
 
-    NvCtrlAttributeHandle *attribute_handle;
+    CtrlTarget *ctrl_target;
     CtkConfig *ctk_config;
 
     GtkWidget *adaptive_clock_status;
@@ -72,6 +71,9 @@ struct _CtkPowermizer
     gboolean  dp_toggle_warning_dlg_shown;
     gboolean  hasDecoupledClock;
     gboolean  hasEditablePerfLevel;
+    gboolean  editable_performance_levels_unified;
+    gint      nvclock_attribute;
+    gint      mem_transfer_rate_attribute;
     gint      attribute;
     gint      powermizer_default_mode;
     GtkWidget *status;
@@ -90,8 +92,8 @@ struct _CtkPowermizerClass
 };
 
 GType          ctk_powermizer_get_type    (void) G_GNUC_CONST;
-GtkWidget*     ctk_powermizer_new         (NvCtrlAttributeHandle *,
-                                           CtkConfig *, CtkEvent *);
+GtkWidget*     ctk_powermizer_new         (CtrlTarget *, CtkConfig *,
+                                           CtkEvent *);
 GtkTextBuffer* ctk_powermizer_create_help (GtkTextTagTable *, CtkPowermizer *);
 
 void           ctk_powermizer_start_timer (GtkWidget *);
